@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.datastore_admin_v1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -218,9 +229,9 @@ class DatastoreAdminAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DatastoreAdminTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the datastore admin client.
@@ -264,14 +275,14 @@ class DatastoreAdminAsyncClient:
 
     async def export_entities(
         self,
-        request: Union[datastore_admin.ExportEntitiesRequest, dict] = None,
+        request: Optional[Union[datastore_admin.ExportEntitiesRequest, dict]] = None,
         *,
-        project_id: str = None,
-        labels: Mapping[str, str] = None,
-        entity_filter: datastore_admin.EntityFilter = None,
-        output_url_prefix: str = None,
+        project_id: Optional[str] = None,
+        labels: Optional[MutableMapping[str, str]] = None,
+        entity_filter: Optional[datastore_admin.EntityFilter] = None,
+        output_url_prefix: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Exports a copy of all or a subset of entities from
@@ -311,13 +322,13 @@ class DatastoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.ExportEntitiesRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.ExportEntitiesRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.ExportEntities][google.datastore.admin.v1.DatastoreAdmin.ExportEntities].
             project_id (:class:`str`):
@@ -327,7 +338,7 @@ class DatastoreAdminAsyncClient:
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (:class:`Mapping[str, str]`):
+            labels (:class:`MutableMapping[str, str]`):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -445,14 +456,14 @@ class DatastoreAdminAsyncClient:
 
     async def import_entities(
         self,
-        request: Union[datastore_admin.ImportEntitiesRequest, dict] = None,
+        request: Optional[Union[datastore_admin.ImportEntitiesRequest, dict]] = None,
         *,
-        project_id: str = None,
-        labels: Mapping[str, str] = None,
-        input_url: str = None,
-        entity_filter: datastore_admin.EntityFilter = None,
+        project_id: Optional[str] = None,
+        labels: Optional[MutableMapping[str, str]] = None,
+        input_url: Optional[str] = None,
+        entity_filter: Optional[datastore_admin.EntityFilter] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Imports entities into Google Cloud Datastore.
@@ -489,13 +500,13 @@ class DatastoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.ImportEntitiesRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.ImportEntitiesRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.ImportEntities][google.datastore.admin.v1.DatastoreAdmin.ImportEntities].
             project_id (:class:`str`):
@@ -505,7 +516,7 @@ class DatastoreAdminAsyncClient:
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (:class:`Mapping[str, str]`):
+            labels (:class:`MutableMapping[str, str]`):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -624,10 +635,10 @@ class DatastoreAdminAsyncClient:
 
     async def create_index(
         self,
-        request: Union[datastore_admin.CreateIndexRequest, dict] = None,
+        request: Optional[Union[datastore_admin.CreateIndexRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates the specified index. A newly created index's initial
@@ -670,13 +681,13 @@ class DatastoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.CreateIndexRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.CreateIndexRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.CreateIndex][google.datastore.admin.v1.DatastoreAdmin.CreateIndex].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -734,10 +745,10 @@ class DatastoreAdminAsyncClient:
 
     async def delete_index(
         self,
-        request: Union[datastore_admin.DeleteIndexRequest, dict] = None,
+        request: Optional[Union[datastore_admin.DeleteIndexRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes an existing index. An index can only be deleted if it is
@@ -779,13 +790,13 @@ class DatastoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.DeleteIndexRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.DeleteIndexRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.DeleteIndex][google.datastore.admin.v1.DatastoreAdmin.DeleteIndex].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -846,10 +857,10 @@ class DatastoreAdminAsyncClient:
 
     async def get_index(
         self,
-        request: Union[datastore_admin.GetIndexRequest, dict] = None,
+        request: Optional[Union[datastore_admin.GetIndexRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> index.Index:
         r"""Gets an index.
@@ -880,7 +891,7 @@ class DatastoreAdminAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.GetIndexRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.GetIndexRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.GetIndex][google.datastore.admin.v1.DatastoreAdmin.GetIndex].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -938,10 +949,10 @@ class DatastoreAdminAsyncClient:
 
     async def list_indexes(
         self,
-        request: Union[datastore_admin.ListIndexesRequest, dict] = None,
+        request: Optional[Union[datastore_admin.ListIndexesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIndexesAsyncPager:
         r"""Lists the indexes that match the specified filters.
@@ -976,7 +987,7 @@ class DatastoreAdminAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.datastore_admin_v1.types.ListIndexesRequest, dict]):
+            request (Optional[Union[google.cloud.datastore_admin_v1.types.ListIndexesRequest, dict]]):
                 The request object. The request for
                 [google.datastore.admin.v1.DatastoreAdmin.ListIndexes][google.datastore.admin.v1.DatastoreAdmin.ListIndexes].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1050,14 +1061,9 @@ class DatastoreAdminAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-datastore-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DatastoreAdminAsyncClient",)
