@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.datastore_admin_v1.types import index as gda_index
@@ -64,7 +66,7 @@ class CommonMetadata(proto.Message):
         operation_type (google.cloud.datastore_admin_v1.types.OperationType):
             The type of the operation. Can be used as a
             filter in ListOperationsRequest.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             The client-assigned labels which were
             provided when the operation was created. May
             also include additional labels.
@@ -83,27 +85,27 @@ class CommonMetadata(proto.Message):
         FAILED = 6
         CANCELLED = 7
 
-    start_time = proto.Field(
+    start_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    operation_type = proto.Field(
+    operation_type: "OperationType" = proto.Field(
         proto.ENUM,
         number=3,
         enum="OperationType",
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=5,
         enum=State,
@@ -123,11 +125,11 @@ class Progress(proto.Message):
             unavailable.
     """
 
-    work_completed = proto.Field(
+    work_completed: int = proto.Field(
         proto.INT64,
         number=1,
     )
-    work_estimated = proto.Field(
+    work_estimated: int = proto.Field(
         proto.INT64,
         number=2,
     )
@@ -141,7 +143,7 @@ class ExportEntitiesRequest(proto.Message):
         project_id (str):
             Required. Project ID against which to make
             the request.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Client-assigned labels.
         entity_filter (google.cloud.datastore_admin_v1.types.EntityFilter):
             Description of what data from the project is
@@ -171,21 +173,21 @@ class ExportEntitiesRequest(proto.Message):
             without conflict.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
     )
-    entity_filter = proto.Field(
+    entity_filter: "EntityFilter" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="EntityFilter",
     )
-    output_url_prefix = proto.Field(
+    output_url_prefix: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -199,7 +201,7 @@ class ImportEntitiesRequest(proto.Message):
         project_id (str):
             Required. Project ID against which to make
             the request.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Client-assigned labels.
         input_url (str):
             Required. The full resource URL of the external storage
@@ -225,20 +227,20 @@ class ImportEntitiesRequest(proto.Message):
             specified then all entities from the export are imported.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
     )
-    input_url = proto.Field(
+    input_url: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    entity_filter = proto.Field(
+    entity_filter: "EntityFilter" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="EntityFilter",
@@ -258,7 +260,7 @@ class ExportEntitiesResponse(proto.Message):
             Only present if the operation completed successfully.
     """
 
-    output_url = proto.Field(
+    output_url: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -287,27 +289,27 @@ class ExportEntitiesMetadata(proto.Message):
             [google.datastore.admin.v1.ExportEntitiesResponse.output_url][google.datastore.admin.v1.ExportEntitiesResponse.output_url].
     """
 
-    common = proto.Field(
+    common: "CommonMetadata" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="CommonMetadata",
     )
-    progress_entities = proto.Field(
+    progress_entities: "Progress" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Progress",
     )
-    progress_bytes = proto.Field(
+    progress_bytes: "Progress" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Progress",
     )
-    entity_filter = proto.Field(
+    entity_filter: "EntityFilter" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="EntityFilter",
     )
-    output_url_prefix = proto.Field(
+    output_url_prefix: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -335,27 +337,27 @@ class ImportEntitiesMetadata(proto.Message):
             field.
     """
 
-    common = proto.Field(
+    common: "CommonMetadata" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="CommonMetadata",
     )
-    progress_entities = proto.Field(
+    progress_entities: "Progress" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Progress",
     )
-    progress_bytes = proto.Field(
+    progress_bytes: "Progress" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Progress",
     )
-    entity_filter = proto.Field(
+    entity_filter: "EntityFilter" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="EntityFilter",
     )
-    input_url = proto.Field(
+    input_url: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -380,9 +382,9 @@ class EntityFilter(proto.Message):
     The entire Baz namespace: kinds=[], namespace_ids=['Baz']
 
     Attributes:
-        kinds (Sequence[str]):
+        kinds (MutableSequence[str]):
             If empty, then this represents all kinds.
-        namespace_ids (Sequence[str]):
+        namespace_ids (MutableSequence[str]):
             An empty list represents all namespaces. This
             is the preferred usage for projects that don't
             use namespaces.
@@ -393,11 +395,11 @@ class EntityFilter(proto.Message):
             Each namespace in this list must be unique.
     """
 
-    kinds = proto.RepeatedField(
+    kinds: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    namespace_ids = proto.RepeatedField(
+    namespace_ids: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
@@ -417,11 +419,11 @@ class CreateIndexRequest(proto.Message):
             deleted.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    index = proto.Field(
+    index: gda_index.Index = proto.Field(
         proto.MESSAGE,
         number=3,
         message=gda_index.Index,
@@ -439,11 +441,11 @@ class DeleteIndexRequest(proto.Message):
             The resource ID of the index to delete.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    index_id = proto.Field(
+    index_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -460,11 +462,11 @@ class GetIndexRequest(proto.Message):
             The resource ID of the index to get.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    index_id = proto.Field(
+    index_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -487,19 +489,19 @@ class ListIndexesRequest(proto.Message):
             request, if any.
     """
 
-    project_id = proto.Field(
+    project_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=4,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -510,7 +512,7 @@ class ListIndexesResponse(proto.Message):
     [google.datastore.admin.v1.DatastoreAdmin.ListIndexes][google.datastore.admin.v1.DatastoreAdmin.ListIndexes].
 
     Attributes:
-        indexes (Sequence[google.cloud.datastore_admin_v1.types.Index]):
+        indexes (MutableSequence[google.cloud.datastore_admin_v1.types.Index]):
             The indexes.
         next_page_token (str):
             The standard List next-page token.
@@ -520,12 +522,12 @@ class ListIndexesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    indexes = proto.RepeatedField(
+    indexes: MutableSequence[gda_index.Index] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gda_index.Index,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -546,17 +548,17 @@ class IndexOperationMetadata(proto.Message):
             acting on.
     """
 
-    common = proto.Field(
+    common: "CommonMetadata" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="CommonMetadata",
     )
-    progress_entities = proto.Field(
+    progress_entities: "Progress" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Progress",
     )
-    index_id = proto.Field(
+    index_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -581,12 +583,12 @@ class DatastoreFirestoreMigrationMetadata(proto.Message):
             Datastore to Cloud Firestore in Datastore mode.
     """
 
-    migration_state = proto.Field(
+    migration_state: migration.MigrationState = proto.Field(
         proto.ENUM,
         number=1,
         enum=migration.MigrationState,
     )
-    migration_step = proto.Field(
+    migration_step: migration.MigrationStep = proto.Field(
         proto.ENUM,
         number=2,
         enum=migration.MigrationStep,
