@@ -40,19 +40,19 @@ KEY_PATHS = (
     EDDARD + ("Character", "Jon Snow"),
 )
 CHARACTERS = (
-    {"name": u"Rickard", "family": u"Stark", "appearances": 0, "alive": False},
-    {"name": u"Eddard", "family": u"Stark", "appearances": 9, "alive": False},
+    {"name": "Rickard", "family": "Stark", "appearances": 0, "alive": False},
+    {"name": "Eddard", "family": "Stark", "appearances": 9, "alive": False},
     {
-        "name": u"Catelyn",
-        "family": [u"Stark", u"Tully"],
+        "name": "Catelyn",
+        "family": ["Stark", "Tully"],
         "appearances": 26,
         "alive": False,
     },
-    {"name": u"Arya", "family": u"Stark", "appearances": 33, "alive": True},
-    {"name": u"Sansa", "family": u"Stark", "appearances": 31, "alive": True},
-    {"name": u"Robb", "family": u"Stark", "appearances": 22, "alive": False},
-    {"name": u"Bran", "family": u"Stark", "appearances": 25, "alive": True},
-    {"name": u"Jon Snow", "family": u"Stark", "appearances": 32, "alive": True},
+    {"name": "Arya", "family": "Stark", "appearances": 33, "alive": True},
+    {"name": "Sansa", "family": "Stark", "appearances": 31, "alive": True},
+    {"name": "Robb", "family": "Stark", "appearances": 22, "alive": False},
+    {"name": "Bran", "family": "Stark", "appearances": 25, "alive": True},
+    {"name": "Jon Snow", "family": "Stark", "appearances": 32, "alive": True},
 )
 LARGE_CHARACTER_TOTAL_OBJECTS = 2500
 LARGE_CHARACTER_NAMESPACE = "LargeCharacterEntity"
